## Aragoa classif and trees: place unplaced

library(ape)
library(shipunov)

DIR <-  dir("data")
trees <- c("fullnah_mb")
for(t in trees) {
assign(t, read.tree(paste0("data/",  DIR[grepl(t, DIR)])))
}
tree <- fullnah_mb
tree$node.label[tree$node.label == "NA"] <- ""
ptree <- drop.tip(tree, grep("Aragoa", tree$tip.label, invert=TRUE))
pc <- cmdscale(cophenetic(ptree), k=3)
row.names(pc) <- gsub("__.*$", "", row.names(pc))
row.names(pc) <- gsub("_", " ", row.names(pc))
row.names(pc) <- gsub("Aragoa lucidula lucidula", "Aragoa lucidula", row.names(pc))
row.names(pc) <- gsub("Aragoa sp. Cundinamarca", "Aragoa cupressina", row.names(pc))

aa <- read.table("data/aragoa_classif_noh.txt", sep="\t", as.is=TRUE)
atree <- read.tree(text=Biokey(aa, from="classif", to="newick"))
ac <- cmdscale(cophenetic(compute.brlen(atree)), k=3)
row.names(ac) <- gsub("_", " ", row.names(ac))

missed <- row.names(ac)[!row.names(ac) %in% row.names(pc)]

merged <- merge(ac, pc, by=0, all=TRUE)
cl <- gsub("\\.[1-9]+$", "", merged$Row.names)
merged <- merged[, -1]
cl <- gsub("\\.", " ", cl)
cl <- gsub("perez arbelaeziana", "perez-arbelaeziana", cl)

MAT <- as.matrix(merged)
row.names(MAT) <- cl

MAT.missed <- MAT[row.names(MAT) %in% missed, ]
MAT.known <- MAT[!row.names(MAT) %in% missed, ]

B <- 1000
PRED <- matrix(nrow=nrow(MAT.missed), ncol=B, dimnames=list(row.names(MAT.missed)))
for (i in 1:B) {
 cat(".")
 MAT.known.b <- MAT.known[sample(nrow(MAT.known), replace=TRUE), ]
 MAT.dist <- dist(rbind(MAT.known.b, MAT.missed), method="manhattan")
 PRED[, i] <- DNN(MAT.dist, factor(c(row.names(MAT.known.b), rep(NA, nrow(MAT.missed)))), k=7)
}
DEV <- vector(mode="list", length=nrow(PRED))
names(DEV) <- row.names(PRED)
for (n in 1:nrow(PRED)) {
 TT <- sort(table(PRED[n, ]), decreasing=TRUE)
 DEV[[n]] <- round(100*(TT[1:3]/B))
 names(DEV[[n]]) <- names(TT)[1:3]
}

placements <- data.frame(do.call(rbind, lapply(DEV, names)), do.call(rbind, DEV))
placements <- placements[, matrix(names(placements), nrow=2, byrow=TRUE)] # interleave columns
write.table(placements, "data/aragoa_placements.txt", col.names=FALSE, quote=FALSE, sep="\t")
