library(ape)
library(shipunov)

DIR <-  dir("data")
trees <- c("tall_mb")
for(t in trees) {
assign(t, read.tree(paste0("data/",  DIR[grepl(t, DIR)])))
}
tree <- tall_mb
tree$node.label[tree$node.label == "NA"] <- ""

## color edges by genera
colo <- rep("grey", dim(tree$edge)[1])
focus <- list(grep("Aragoa", tree$tip.label), grep("Littorella", tree$tip.label), grep("Plantago", tree$tip.label))
colors <- c("black", "purple3", "forestgreen")
for (i in 1:length(focus)) colo[which.edge(tree, focus[[i]])] <- colors[i]

## thickness for support
all.nodes <- c(rep(FALSE, length(tree$tip.label)), as.numeric(tree$node.label) > 90)
all.nodes[is.na(all.nodes)] <- FALSE
thick <- 3
## with segments:
sel.e <- tree$edge[tree$edge[, 2] %in% which(all.nodes), ]
col.e <- colo[tree$edge[, 2] %in% which(all.nodes)]
xx0 <- node.depth.edgelength(tree)[sel.e[, 1]]
xx1 <- node.depth.edgelength(tree)[sel.e[, 2]]
yy1 <- node.height(tree)[sel.e[, 2]]

pdf("data/plantago_tree_support.pdf")
plot.phylo(tree, edge.color=colo, show.tip.label=FALSE, no.margin=T)
segments(x0=xx0, y0=yy1, x1=xx1, y1=yy1, lwd=thick, lend=1, col=col.e)
legend("bottomright", fill=colors, legend=c("Aragoa", "Littorella", "Plantago"), bty="n")
dev.off()
