library(ape)
library(vegan)
library(MASS)
library(shipunov)

DIR <-  dir("data")
trees <- c("tall_mb", "mm_mb", "broad_mb")
for(t in trees) {
assign(t, read.tree(paste0("data/",  DIR[grepl(t, DIR)])))
}

morph <- read.table("data/plantago_morph.txt", sep="\t", as.is=T, h=T)
classif <- read.table("../../../data/plantago_sp.txt", h=T, sep="\t", as.is=T)
char <-  read.table("../../../data/plantago_char.txt", sep="\t", h=T, quote="", as.is=T)

## UNIFICATION
tree <- tall_mb
tree$tip.label <- sub("__.*$", "", tree$tip.label)
tree$tip.label <- gsub("^([^_]*_[^_]*)_.*$", "\\1", tree$tip.label)
tree$tip.label <- gsub("_", " ", tree$tip.label)
ptree0 <- drop.tip(tree, grep("Plantago", tree$tip.label, invert=T))
ptree1 <- drop.tip(ptree0, grep("Plantago sp.", ptree0$tip.label))
ptree2 <- drop.tip(ptree1, ptree1$tip.label[duplicated(ptree1$tip.label)])
ptree1$tip.label <- make.unique(ptree1$tip.label)
ptree2 <- drop.tip(ptree1, ptree1$tip.label[grepl("[1-9]", ptree1$tip.label)])

morph2 <- morph[!duplicated(morph$SPECIES.NEW), ]
row.names(morph2) <- morph2$SPECIES.NEW
morph2[, c("SPECIES.NEW", "USE", "SP.RAHN", "SP.ID.RAHN")] <- NULL

both <- intersect(row.names(morph2), ptree2$tip.label)
morph3 <- morph2[row.names(morph2) %in% both, ]
ptree3 <- drop.tip(ptree2, ptree2$tip.label[!ptree2$tip.label %in% both])

## BOTH INTO METRIC MAPS
mc <- monoMDS(vegdist(morph3, method="gower", na.rm=T))
pc <- monoMDS(cophenetic.phylo(ptree3))
mc$points <- mc$points[both, ]
pc$points <- pc$points[both, ]

(proc <- procrustes(mc, pc))
protest(mc, pc)

classif <- classif[grep("Plantago", classif$SPECIES), ]
subg <- Recode(row.names(proc$X), classif$SPECIES, classif$SUBGENUS)
colors <- as.numeric(factor(subg))

pdf("data/plantago_mm.pdf")
plot(proc, ar.col=colors, main="", xlab="Dim.1", ylab="Dim.2")
legend("bottomright", fill=1:3, legend=levels(factor(subg)))
dev.off()
