## MWMC

library(ape)
library(MASS)
library(shipunov)
source("data/make_treesc.r")

DIR <-  dir("data")
trees <- c("tall_mb", "mm_mb", "broad_mb")
for(t in trees) {
assign(t, read.tree(paste0("data/",  DIR[grepl(t, DIR)])))
}

morph <- read.table("data/plantago_morph.txt", sep="\t", as.is=T, h=T)
char <-  read.table("../../../data/plantago_char.txt", sep="\t", h=T, quote="", as.is=T)

row.names(morph) <- make.unique(morph$SPECIES.NEW)
morph[, c("SPECIES.NEW", "USE", "SP.RAHN", "SP.ID.RAHN", "RADV.01")] <- NULL
na.rows.morph <- apply(morph, 1, function(.x) sum(is.na(.x)) == length(.x))
morphn <- morph[!na.rows.morph, ] # remove species with no data
morphn[is.na(morphn)] <- 0 # discussable but useful

## MWMC based on mm (a.k.a. loadings)
mm <- Make.treesc(list(mm_mb))[[1]]
both.mm <- intersect(row.names(morphn), mm$tip.label)
m.mm <- morphn[row.names(morphn) %in% both.mm, ]
mm <- drop.tip(mm, mm$tip.label[!mm$tip.label %in% both.mm])
cm.mm <- cmdscale(cophenetic(mm), k=3)
cor.mm <- cor(m.mm, cm.mm, method="spearman")
cor.mm[is.na(cor.mm)] <- 0
avgcor <- apply(cor.mm, 1, function(.x) sum(abs(.x), na.rm=TRUE)/3)
mm.mw <- sort(avgcor, decreasing=TRUE)[1:10]

## MWMC based on tall
tall <- Make.treesc(list(tall_mb))[[1]]
both.tall <- intersect(row.names(morphn), tall$tip.label)
m.tall <- morphn[row.names(morphn) %in% both.tall, ]
tall <- drop.tip(tall, tall$tip.label[!tall$tip.label %in% both.tall])
cm.tall <- cmdscale(cophenetic(tall), k=3)
cor.tall <- cor(m.tall, cm.tall, method="spearman")
cor.tall[is.na(cor.tall)] <- 0
avgcor <- apply(cor.tall, 1, function(.x) sum(abs(.x), na.rm=TRUE)/3)
tl.mw <- sort(avgcor, decreasing=TRUE)[1:10]

pdf("data/plantago_morph_weights.pdf")
par(mfrow=c(1, 2))
Dotchart(rev(mm.mw), main="combined")
Dotchart(rev(tl.mw), main='"tall"')
dev.off()
