library(ape)
library(MASS)
library(shipunov)

DIR <-  dir("data")
trees <- "tall_mb"
for(t in trees) {
assign(t, read.tree(paste0("data/",  DIR[grepl(t, DIR)])))
}

morph <- read.table("../../../data/plantago_my.txt", sep="\t", as.is=TRUE, h=TRUE)

ma1 <- Aggregate1(morph[, morph %-% c("SPECIES", "SAMPLE", "GAP", "TAPROOT")], morph$SAMPLE, median, na.rm=TRUE)
ma2 <- Aggregate1(morph[, c("GAP", "TAPROOT")], morph$SAMPLE, function(.x) sort(.x, decreasing=TRUE)[1])
ma <- cbind(ma1, ma2)

tall <- keep.tip(tall_mb, tall_mb$tip.label[grepl("P-[0-9]+", tall_mb$tip.label)])
tall$tip.label <- gsub("^.*(P-[0-9]+).*$", "\\1", tall$tip.label)
ma <- ma[row.names(ma) %in% tall$tip.label, ]
tall <- keep.tip(tall, tall$tip.label[tall$tip.label %in% row.names(ma)])

cm.tall <- cmdscale(cophenetic(tall), k=3)
## without replication:
## cor.tall <- cor(ma, cm.tall, method="spearman", use="pairwise.complete.obs")
## cor.tall[is.na(cor.tall)] <- 0
## with replication:
cc <- vector("list", 1000)
for (n in 1:length(cc)) {
.n <- sample(nrow(ma))
cc[[n]] <- cor(ma[.n, ], cm.tall[.n, ], method="spearman", use="pairwise.complete.obs")
}
cor.tall <- apply(simplify2array(cc), 1:2, median)
## uses median() and max() instead of sum(...)/n like in 'morph.weights.r'
avgcor.median <- apply(cor.tall, 1, function(.x) median(abs(.x), na.rm=TRUE))
mspot.mw.median <- sort(avgcor.median, decreasing=TRUE)
avgcor.max <- apply(cor.tall, 1, function(.x) max(abs(.x), na.rm=TRUE))
mspot.mw.max <- sort(avgcor.max, decreasing=TRUE)

pdf("data/plantago_mspot_weights.pdf")
par(mfrow=c(1, 2))
Dotchart(rev(mspot.mw.median), main="median")
Dotchart(rev(mspot.mw.max), main="maximum")
dev.off()







