library(ape)
library(shipunov)
library(vegan)
library(class)
library(parallelDist)
source("data/make_treesc.r")

morph <- read.table("data/plantago_morph.txt", sep="\t", as.is=TRUE, h=TRUE)
morph <- morph[grep("Plantago", morph$SPECIES.NEW), ]

classif <- read.table("data/plantago_classif.txt", sep="\t", as.is=TRUE, h=TRUE)
to.place <- scan("data/plantago_place.txt", what="char", sep="\t")

DIR <-  dir("data")
trees <- c("tall_mb", "broad_mb", "plastome_mb.tre")
treelist <- vector("list", length=length(trees))
names(treelist) <- trees

for(t in trees) treelist[[t]] <- read.tree(paste0("data/",  DIR[grepl(t, DIR)]))
treelist <- lapply(treelist, function(.x) drop.tip(.x, grep("Plantago", .x$tip.label, invert=TRUE)))
treelist <- lapply(treelist, function(.x) Make.treesc(list(.x))[[1]])
## Hcl2mat() loses row names and have objects as columns so:
treelist <- lapply(treelist, 
 function(.x) { .m <- t(Hcl2mat(as.hclust(compute.brlen(multi2di(.x))))); row.names(.m) <- .x$tip.label; .m })

m12 <- merge(treelist[[1]], treelist[[2]], by=0, all=TRUE)
m123 <- merge(m12, treelist[[3]], by.x="Row.names", by.y=0, all=TRUE)
merged <- merge(m123, morph[, -(2:4)], , by.x="Row.names", by.y="SPECIES.NEW", all=TRUE)
cl <- merged$Row.names

no.dna <- morph$SPECIES.NEW[!morph$SPECIES.NEW %in% m123$Row.names]
missed <- union(to.place, no.dna)

MAT <- as.matrix(merged[, merged %-% "Row.names"])
colnames(MAT) <- paste0("M", 1:ncol(MAT))
row.names(MAT) <- cl

MAT.missed <- MAT[row.names(MAT) %in% missed, ]
MAT.known <- MAT[!row.names(MAT) %in% missed, ]
row.names(MAT.known) <- Recode4(row.names(MAT.known), classif$SPECIES, classif$SERIES)
MAT.known <- MAT.known[row.names(MAT.known) != "", ] # remove leftovers, if any

B <- 100
PRED <- matrix(nrow=nrow(MAT.missed), ncol=B, dimnames=list(row.names(MAT.missed)))
for (i in 1:B) {
 cat(".")
 MAT.known.b <- MAT.known[sample(nrow(MAT.known), replace=TRUE), ]
 MAT.dist <- dist(rbind(MAT.known.b, MAT.missed), method="binary")
 PRED[, i] <- DNN(MAT.dist, factor(c(row.names(MAT.known.b), rep(NA, nrow(MAT.missed)))), k=7)
}
DEV <- vector(mode="list", length=nrow(PRED))
names(DEV) <- row.names(PRED)
for (n in 1:nrow(PRED)) {
 TT <- sort(table(PRED[n, ]), decreasing=TRUE)
 DEV[[n]] <- round(100*(TT[1:3]/B))
 names(DEV[[n]]) <- names(TT)[1:3]
}
placements <- data.frame(do.call(rbind, lapply(DEV, names)), do.call(rbind, DEV))
placements <- placements[, matrix(names(placements), nrow=2, byrow=TRUE)] # interleave columns
write.table(placements, "data/plantago_placements.txt", col.names=FALSE, quote=FALSE, sep="\t")

MAT.known <- MAT[!row.names(MAT) %in% missed, ]
subg <- Recode4(row.names(MAT.known), classif$SPECIES, classif$SUBGENUS)
MAT.known <- MAT.known[subg != "" & subg != "Bougueria", ]
subg <- subg[subg != "" & subg != "Bougueria"]
set.seed(0)
ORD <- monoMDS(vegdist(MAT.known, method="manhattan", na.rm=TRUE))$points
colors <- adjustcolor(as.numeric(factor(subg)), alpha.f=.3)
pdf("data/plantago_nn.pdf")
plot(ORD, col=colors, pch=19, xlab="Dim.1", ylab="Dim.2")
Gradd(cbind(subg, ORD), ORD, palette=unique(colors), pch=16, cex=1, type="user",
User.Predict=function(model2var, X) knn(model2var[, 2:3], X, model2var[, 1], k=5))
## Gradd(model2var=data.frame(subg, ORD), data2var=ORD, palette=unique(colors), pch=16, cex=1, type="user",
##  User.Predict=function(model2var, X) Dnn(trn=model2var[, 2:3], tst=X, classes=subg, k=5,
#### FUN=function(.x) parDist(as.matrix(.x), threads=4))) # only slightly better with parDist()
## )) # slow!
dev.off()
