library(rpart)
library(rpart.plot)
library(ape)
library(shipunov)

## Hoepke's et al. treshold approach was not very efective (at least for keying)

morph <- read.table("data/plantago_morph.txt", sep="\t", as.is=T, h=T)
morph <- morph[, !grepl("SDTYPE", names(morph))] # remove sculpture
morph <- morph[, !grepl(".89$", names(morph))] # remove cotyledons
morph <- morph[, !grepl(".90$", names(morph))] # remove chromosome number
morph <- morph[, !grepl(".91$", names(morph))] # remove ribose
classif <- read.table("data/plantago_classif_new.txt", sep="\t", as.is=TRUE, h=TRUE)
secser <- Recode4(morph$SPECIES.NEW, classif$SPECIES, classif$SECTIO)
good <- !(secser == "" | secser == "Incertae sedis")
morph <- morph[good, ]
secser <- secser[good]
morf <- as.data.frame(sapply(morph[, -(1:4)], as.factor))
tree <- rpart(secser ~ ., data=morf, method="class", control=rpart.control(minsplit=2, minbucket=1))

Misclass(predict(tree, type="class"), secser)
printcp(tree)
(tree$variable.importance / max(tree$variable.importance)) * 100

pdf("data/plantago_rpart.pdf", width=11)
prp(tree, type=0, extra=3, compress=TRUE, ycompress=TRUE, cex=0.7, varlen=0)
dev.off()

# ===

used <- as.character(unique(tree$frame$var[tree$frame$var != "<leaf>"]))
morf2 <- morf[, morf %-% used]
tree2 <- rpart(secser ~ ., data=morf2, method="class", control=rpart.control(minsplit=2, minbucket=1))

Misclass(predict(tree2, type="class"), secser)
printcp(tree2)
(tree2$variable.importance / max(tree2$variable.importance)) * 100

pdf("data/plantago_rpart2.pdf", width=11)
prp(tree2, type=0, extra=3, compress=TRUE, ycompress=TRUE, cex=0.7, varlen=0)
dev.off()

# ===

used2 <- as.character(unique(tree2$frame$var[tree2$frame$var != "<leaf>"]))
morf3 <- morf2[, morf2 %-% used2]
tree3 <- rpart(secser ~ ., data=morf3, method="class", control=rpart.control(minsplit=2, minbucket=1))

Misclass(predict(tree3, type="class"), secser)
printcp(tree3)
(tree3$variable.importance / max(tree3$variable.importance)) * 100

pdf("data/plantago_rpart3.pdf", width=11)
prp(tree3, type=0, extra=3, compress=TRUE, ycompress=TRUE, cex=0.7, varlen=0)
dev.off()

# ===

my <- read.table("../../../data/plantago_my.txt", sep="\t", as.is=TRUE, h=TRUE)
ma1 <- Aggregate1(my[, -c(1:2, 8:9)], my$SPECIES, median, na.rm=TRUE)
ma2 <- Aggregate1(my[, c("GAP", "TAPROOT")], my$SPECIES, function(.x) sort(.x, decreasing=TRUE)[1])
ma <- cbind(ma1, ma2)

secser <- Recode4(row.names(ma), classif$SPECIES, classif$SECTIO)
good <- !(secser == "" | secser == "Incertae sedis")
ma <- ma[good, ]
secser <- secser[good]
tree4 <- rpart(secser ~ ., data=ma, control=rpart.control(minbucket=5))

Misclass(predict(tree4, type="class"), secser)
printcp(tree4)
(tree4$variable.importance / max(tree4$variable.importance)) * 100

pdf("data/plantago_rpart_mspot.pdf")
prp(tree4, type=0, extra=3, compress=TRUE, ycompress=TRUE, cex=0.7, varlen=0)
dev.off()
