library(shipunov)

morph <- read.table("../../../data/plantago_my.txt", sep="\t", as.is=TRUE, h=TRUE)
classif <- read.table("data/plantago_classif.txt", h=TRUE, sep="\t", as.is=TRUE)
reg <- read.table("../../../data/plantago_reg.txt", h=TRUE, sep="\t", as.is=TRUE)

ma1 <- Aggregate1(morph[, -c(1:2, 8:9)], morph$SPECIES, median, na.rm=TRUE)
ma2 <- Aggregate1(morph[, c("GAP", "TAPROOT")], morph$SPECIES, function(.x) sort(.x, decreasing=TRUE)[1])
ma <- cbind(ma1, ma2)

RL <- with(ma, LEAF.L/LEAF.W)
SL <- as.character(RL)
SL[RL > 10] <- "l.linear" # introduced from Rahn's character 10
SL[RL > 5 & RL <= 10] <- "linear"
SL[RL < 1.1] <- "circular"
SL[RL >= 1.1 & RL <= 2] <- "elliptic"
SL[RL > 2 & RL <= 5] <- "oblong"
ma$L.SHAPE <- SL
ma$SPECIES <- row.names(ma)

## will sequentially merge multiple data frames by twos
cr <- Reduce(function(df1, df2) merge(df1, df2, by="SPECIES"), list(classif, reg, ma))
cr$L.SHAPE <- factor(cr$L.SHAPE, levels=c("elliptic", "oblong", "linear", "l.linear"))

## with(cr, table(SECTIO, REGION2))
chisq.test(with(cr, table(SECTIO, REGION2)), simulate.p.value=TRUE) # good
VTcoeffs(with(cr, table(SECTIO, REGION2)))[2, ] # large

## with(cr, table(SUBGENUS, L.SHAPE))
chisq.test(with(cr, table(SUBGENUS, L.SHAPE)), simulate.p.value=TRUE) # good
VTcoeffs(with(cr, table(SUBGENUS, L.SHAPE)))[2, ] # large
pdf("data/plantago_leaf_shape_subgenus.pdf")
spineplot(with(cr, table(SUBGENUS, L.SHAPE)))
dev.off()

## with(cr, table(SECTIO, L.SHAPE))
chisq.test(with(cr, table(SECTIO, L.SHAPE)), simulate.p.value=TRUE) # good
VTcoeffs(with(cr, table(SECTIO, L.SHAPE)))[2, ] # large

## with(cr, table(REGION, L.SHAPE))
chisq.test(with(cr, table(REGION2, L.SHAPE)), simulate.p.value=TRUE) # not bad
VTcoeffs(with(cr, table(REGION2, L.SHAPE)))[2, ] # medium

## OTHER SPOT CHARACTERS

## LEAF.L > (STALK + SPIKE)
SHORT <- with(cr, ((STALK + SPIKE) < LEAF.L))
chisq.test(with(cr, table(SECTIO, SHORT)), simulate.p.value=TRUE) # bad
## VTcoeffs(with(cr, table(SECTIO, SHORT)))[2, ]

## SPIKE >= STALK
TAIL <- with(cr, (SPIKE >= STALK))
chisq.test(with(cr, table(SECTIO, TAIL)), simulate.p.value=TRUE) # worse
## VTcoeffs(with(cr, table(SECTIO, TAIL)))[2, ]

## GAP
chisq.test(with(cr, table(SECTIO, GAP)), simulate.p.value=TRUE) # good
VTcoeffs(with(cr, table(SECTIO, GAP)))[2, ] # medium

## TAPROOT
## SECTIO does not work (zero marginals)
chisq.test(with(cr, table(SUBGENUS, TAPROOT)), simulate.p.value=TRUE) # good
VTcoeffs(with(cr, table(SUBGENUS, TAPROOT)))[2, ] # small
