library(shipunov)

classif <- system("grep -E '/[12].[0-9]|\\SYN {' 01_make_sp/plantagineae_classif.tex", intern=TRUE)

GENUS <- ifelse(grepl("2\\.0", classif), gsub("[^ ]* ([^ ]*) .*$", "\\1", classif), "")
SUBGENUS <- ifelse(grepl("1\\.8", classif), gsub("[^ ]* ([^ \\]*).*$", "\\1", classif), "")
SUBGENUS <- ifelse(GENUS == SUBGENUS, SUBGENUS, paste0(GENUS, SUBGENUS))
SECTION <- ifelse(grepl("1\\.5", classif), gsub("[^ ]* ([^ \\]*).*$", "\\1", classif), "")
SECTION <- paste0(SUBGENUS, SECTION)
SUBSECTION <- ifelse(grepl("1\\.2", classif), gsub("[^ ]* ([^ \\]*).*$", "\\1", classif), "")
SUBSECTION <- paste0(SECTION, SUBSECTION)
SPECIES <- ifelse(grepl("1\\.0", classif), gsub(".*\\{(.*)\\}.*$", "\\1", classif), "")
SPECIES <- sub("$\\times$", "", SPECIES, fixed=TRUE) # hybrid signs omitted!
SPECIES[(SUBGENUS != "") | (SECTION != "") | (SUBSECTION != "")] <- NA
SYNONYMS <- ifelse(grepl("\\SYN", classif), gsub(".*\\{([^}]*)\\}.*$", "\\1", classif), NA)

sp <- data.frame(GENUS, SUBGENUS, SECTION, SUBSECTION, SPECIES, SYNONYMS, stringsAsFactors=FALSE)

sp[, sp %-% "SYNONYMS"] <- apply(sp[, sp %-% "SYNONYMS"], 2, Fill)
sp <- sp[!is.na(sp$SPECIES), ]

## check if there are no species duplicates
## sp[which(sp$SPECIES == "Plantago maxima"), ]

## Alternatively, it is possible to define Fill() as
if(0) {
Fill <- function (x, ditto="")
{
 res <- x
 if (is.na(ditto)) {
  while(length(ind <- which(is.na(res))) > 0) res[ind] <- res[ind - 1]
 } else {
  while(length(ind <- which(res == ditto)) > 0) res[ind] <- res[ind - 1]
 }
 res
}
}
## this is faster but same cumsum() required to detach first dittos plus it will fill with NAs

treesp <- read.table("../../data/plantago_treesp.txt", sep="\t", h=TRUE, as.is=TRUE)
outgroup <- treesp["SPECIES.NEW"][treesp$TYPE == "outgroup", , drop=FALSE]
names(outgroup) <- "SPECIES"
outgroup$GENUS <- do.call(rbind, strsplit(outgroup$SPECIES, split=" "))[, 1]
outgroup$SUBGENUS <- NA
outgroup$SECTION <- NA
outgroup$SUBSECTION <- NA
outgroup$SYNONYMS <- NA
outgroup <- rbind(outgroup, outgroup[outgroup$SPECIES == "Tetranema roseum", ])
outgroup$SYNONYMS[nrow(outgroup)] <- "Tetranema mexicanum"

sp <- rbind(sp, outgroup)

write.table(sp, file="../../data/plantago_sp.txt", row.names=FALSE, quote=FALSE, sep="\t")
