library(shipunov)

dna <- read.table("../../data/plantago_dna.txt", sep="\t", h=T, as.is=T, quote="")
samples <- read.table("../../data/plantago_samples.txt", sep="\t", h=T, as.is=T)
sp <- read.table("../../data/plantago_sp.txt", sep="\t", h=T, as.is=T)

## deselected unique species
## all:
sp1 <- setdiff(dna$SPECIES.NEW, dna$SPECIES.NEW[dna$SELECT == 1])
usd <- dna[dna$SPECIES.NEW %in% sp1, -which(names(dna) == "SEQUENCE")]
usd$WHAT <- "all"
## by fragments:
fragments <- c("coi", "its", "rbcl", "trnl", "matk") # fragile
for(f in fragments) {
sp2 <- setdiff(dna$SPECIES.NEW[dna$FRAGMENT == f], dna$SPECIES.NEW[dna$SELECT == 1 & dna$FRAGMENT == f])
sp2 <- sp2[!sp2 %in% sp1]
if (length(sp2) == 0) next
usd.tmp <- dna[dna$FRAGMENT == f & dna$SPECIES.NEW %in% sp2, -which(names(dna) == "SEQUENCE")]
usd.tmp$WHAT <- f
usd <- rbind(usd, usd.tmp)
}
usd <- usd[!duplicated(usd), ]
write.table(usd, file="13_wanted/plantago_unique_sp_deselected.txt", sep="\t", row.names=F, quote=F)

wanted <- data.frame(SPECIES=sort(unique(sp$SPECIES)), stringsAsFactors=F)
wanted$HAD.SAMPLE <- (wanted$SPECIES %in% samples$SPECIES.NEW)
wanted$SAMPLE.LEFT <- (wanted$SPECIES %in% samples$SPECIES.NEW[samples$LEFT == 1  & !is.na(samples$LEFT)])

dna <- dna[dna$SELECT == 1 | is.na(dna$SELECT), ]

wanted$COI <- (wanted$SPECIES %in% dna$SPECIES.NEW[dna$FRAGMENT == "coi"])
wanted$ITS <- (wanted$SPECIES %in% dna$SPECIES.NEW[dna$FRAGMENT == "its"]) * 2
wanted$RBCL <- (wanted$SPECIES %in% dna$SPECIES.NEW[dna$FRAGMENT == "rbcl"])
wanted$TRNL <- (wanted$SPECIES %in% dna$SPECIES.NEW[dna$FRAGMENT == "trnl"]) * 2
wanted$MATK <- (wanted$SPECIES %in% dna$SPECIES.NEW[dna$FRAGMENT == "matk"])

wanted[, -1] <- apply(wanted[, -1], 2, as.numeric)
wanted$MOST.WANTED <- apply(wanted[, -1], 1, function(.x) 9-sum(.x)) # 9 is maximum

write.table(wanted[order(wanted$MOST.WANTED, decreasing=T), ], file="13_wanted/plantago_wanted.txt", sep="\t", row.names=F, quote=F)
