library(shipunov)

## weight of morphological characters to match informative molecular characters (could be lower, e.g., 4 to match trnl or evan 2 to match its)
WMC <- 6

sequences <- read.table("../../data/plantago_dna.txt", sep="\t", h=T, as.is=T, quote="")
tmp1 <- sequences[sequences$SOURCE == "MISU", "SEQUENCE.ID"]
tmp2 <- suppressWarnings(do.call(rbind, strsplit(tmp1, ", ")))
ourids.all <- unique(sort(tmp2))

tall <- read.table("40_concatenated/tall.txt", sep="\t", h=T, as.is=T)
morph <- read.table("../../data/plantago_morph.txt", sep="\t", h=T, as.is=T)

## deduplicate morph
morph <- morph[morph$USE == 1, ]
morph[, c("USE", "SP.RAHN", "SP.ID.RAHN")] <- NULL

## convert 0 to C, 3 to A
morph[is.na(morph)] <- "N"
morph[morph == 3] <- "A"
morph[morph == 0] <- "C"
cat("'bases' stat:\n")
table(unlist(morph[, -1]))

## join as "fragment"
morph$morph1 <- apply(morph[, -1], 1, paste, collapse="")
morph$morph <- apply(morph[, "morph1", drop=F], 1, function(.x) paste(rep(.x, WMC), collapse=""))
morph.f <- morph[, c("SPECIES.NEW", "morph")]

# ===

## write morphology only
monly <- data.frame(ID=morph.f$SPECIES.NEW, SEQ=morph.f$morph)
monly <- monly[!grepl("^N+$", monly$SEQ), ] # remove all missed
monly$ID <- gsub(" +", "_", monly$ID)
## remove duplicates
groups <- as.numeric(as.factor(monly$SEQ))
comb.ids <-  aggregate(monly$ID, by=list(groups), paste, collapse="+")
monly2 <- monly[!duplicated(groups), ] # remove duplicates in main table
monly2$ID <- comb.ids[groups[!duplicated(groups)], 2] # the same order as in deduplicated data
Write.fasta(monly2, file=paste0("40_concatenated/", "morph.fasta"))

# ===

## merge to tall via morph species
mm <- merge(morph.f, tall, by.x="SPECIES.NEW", by.y="SP", all.x=T)
names(mm)[match("SPECIES.NEW", names(mm))] <- "SP"
mm <- mm[, c("SP", "ID", "its.ID", "trnl.ID", "its", "trnl", "morph")]
mm <- mm[!(is.na(mm$its) & is.na(mm$trnl) & grepl("^N+$", mm$morph)), ] # remove all missed
mm <- mm[!(grepl("^N+$", mm$morph)), ] # remove all morpho NA

## "typical" operations on mm including statistics, labels etc.
data <- mm
data.f <- c("its", "trnl")
data.fm <- c("its", "trnl", "morph")
data.f.ids <- paste0(data.f, ".ID")

## make joint ids
ids.tmp0 <- data[, c("SP", "ID", data.f.ids)]
ids.tmp1 <- apply(ids.tmp0[, c("SP", "ID")], 1, function(.x) paste(.x, collapse="__"))
for (i in data.f.ids) ids.tmp0[, i] <- ifelse(is.na(ids.tmp0[, i]), "", paste(sub(".ID", "", i), ids.tmp0[, i]))
ids.tmp2 <- apply(ids.tmp0[, data.f.ids], 1, function(.x) paste(.x, collapse=" "))
ids.tmp2 <- gsub("(^ +)|( +$)", "", ids.tmp2)
ids.tmp2 <- gsub("( +)", " ", ids.tmp2)
ids.tmp <- paste(ids.tmp1, ids.tmp2)
ids.tmp <- gsub(" +", "_", ids.tmp)
ids.tmp <- gsub(",", "", ids.tmp)
ids.tmp <- gsub("_$", "", ids.tmp)
ids.tmp <- gsub("_NA_", "_", ids.tmp)

## mm statistics
data.m <- data.frame(data[, 1:2], apply(data[, data.f], 2, function(.y) ifelse(is.na(.y), 0, 1)))
data.m$morph <- (!grepl("^N+$", data$morph)) * 1
data.m$COUNT <- rowSums(data.m[, data.fm])
## what missed after concatenation
data.m[order(data.m$COUNT, decreasing=T), ]
## how many ids in each missing state
table(apply(data[, data.fm], 1, function(.y) sum(!is.na(.y))))
## how many ids missed in each fragment
apply(data[, data.fm], 2, function(.x) paste0(sum(is.na(.x)), "/", length(.x)))
## how many sequences our and total
all.ids <- unlist(data[, c("ID", paste0(data.f, ".ID"))])
## our
sum(all.ids %in% ourids.all & !is.na(all.ids) & all.ids != "-")
## total
sum(!is.na(all.ids) & all.ids != "-")
## number of potentially informative characters and total number of characters per fragment
for (f in data.fm) {
cat(f)
tmp <- data[, f]
tmp <- tmp[!is.na(tmp)]
tmp.table <- do.call(rbind, strsplit(tmp, split=""))
tmp.table[tmp.table == "-" | tmp.table == "N"] <- NA
cat("\tall chars ", ncol(tmp.table))
tmp.itic <- apply(tmp.table, 2, Is.tax.inform.char)
cat("\tpotentially taxonomically informative chars ", sum(tmp.itic), "\n")
}

## replace NA's with N's and write resulted FASTA
for (i in data.f) data[, i] <- ifelse(is.na(data[, i]), paste(rep("N", max(nchar(data[, i]), na.rm=T)), collapse=""), data[, i])
seq <- apply(data[, data.fm], 1, function(.x) paste(.x, collapse=""))
data.new <- data.frame(ID=ids.tmp, SEQ=seq, stringsAsFactors=F)
Write.fasta(data.new, file=paste0("40_concatenated/", "mm.fasta"))
