library(ape)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")

fragments <- c("coi", "its", "rbcl", "trnl", "matk") # fragile

treesp <- read.table("../../data/plantago_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup" & treesp$USE == 1]
outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier" & treesp$USE == 1]

for (f in fragments) {
cat(f, "\n")
assign(f, read.dna(paste0("33_alignments_trimmed_gapcoded/", f, ".fasta"), format="fasta"))
LAB <- sub("__.*$", "", labels(get(f)))
OUT <- labels(get(f))[LAB %in% outgroups]
EXC <- labels(get(f))[LAB %in% outliers] # is not used
if (f == "coi") {
tree <- nj(dist.dna(get(f))) # because no otgroups have coi fragment
} else {
tree <- Root1(njs(dist.dna(get(f), pairwise.deletion=T)), OUT, resolve.root=T)
}
 pdf(paste("50_technical_trees/", DATE, "_", f, "_nj_plantago.pdf", sep=""), height=32, width=22)
 par(mar=c(0,0,0,0))
 plot(tree)
 mtext(f, line=-3, font=2)
 dev.off()
}
