library(phangorn)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/plantago_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup" & treesp$USE == 1]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier" & treesp$USE == 1]
outliers <- gsub(" ", "_", outliers)

conc <- read.dna("40_concatenated/mm.fasta", format="fasta")
LAB <- sub("__.*$", "", labels(conc))
OUT <- labels(conc)[LAB %in% outgroups]

EXC <- labels(conc)[LAB %in% outliers] # used!
conc <- conc[!labels(conc) %in% EXC, ] # remove outliers

conc.phydat <- phyDat(conc)

conc.pr <- pratchet(conc.phydat, maxit=2000, k=20)
conc.pr <- acctran(conc.pr, conc.phydat)
conc.ptrees <- bootstrap.phyDat(conc.phydat, pratchet, bs=1000, multicore=T)
conc.prr <- Root1(conc.pr, OUT, resolve.root=T)
##
pdf(paste("99_mp_mb_trees/", DATE, "_mm_mp_plantago.pdf", sep=""), height=36, width=32)
oldpar <- par(mar=c(0,0,0,0))
conc.prr.b <- plotBS(conc.prr, conc.ptrees, p=50, type="phylogram")
add.scale.bar()
mtext("mm its + trnl + morph MP", font=2, line=-3)
par(oldpar)
dev.off()
##
conc.prr.b$node.label[conc.prr.b$node.label == "NA"] <- ""
write.tree(conc.prr.b, file=paste("99_mp_mb_trees/", DATE, "_mm_mp_plantago.tre", sep=""))
