library(phangorn)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/plantago_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup" & treesp$USE == 1]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier" & treesp$USE == 1]
outliers <- gsub(" ", "_", outliers)

conc <- read.dna("40_concatenated/tall.fasta", format="fasta")
LAB <- sub("__.*$", "", labels(conc))
OUT <- labels(conc)[LAB %in% outgroups]

EXC <- labels(conc)[LAB %in% outliers]
conc <- conc[!labels(conc) %in% EXC, ] # remove outliers

conc.phydat <- phyDat(conc)

conc.pr <- pratchet(conc.phydat, maxit=2000, minit=100, k=100) # changed here like in bux!
## conc.pr <- pratchet(conc.phydat, maxit=2000, k=20)
conc.pr <- acctran(conc.pr, conc.phydat)
conc.ptrees <- bootstrap.phyDat(conc.phydat, pratchet, bs=1000, multicore=T)
conc.prr <- Root1(conc.pr, OUT, resolve.root=T)
##
pdf(paste("99_mp_mb_trees/", DATE, "_tall_mp_plantago.pdf", sep=""), height=42, width=32)
oldpar <- par(mar=c(0,0,0,0))
conc.prr.b <- plotBS(conc.prr, conc.ptrees, p=50, type="phylogram")
add.scale.bar()
mtext("tall its + trnl MP", font=2, line=-3)
par(oldpar)
dev.off()
##
conc.prr.b$node.label[conc.prr.b$node.label == "NA"] <- ""
write.tree(conc.prr.b, file=paste("99_mp_mb_trees/", DATE, "_tall_mp_plantago.tre", sep=""))

dput(conc.ptrees, file=paste0("99_mp_mb_trees/", DATE, "_tall_mp_ptrees_plantago.rd"))
cons.50 <- consensus(conc.ptrees, p=0.5)
cons.50r <- Root1(cons.50, OUT)
##
pdf(paste0("99_mp_mb_trees/", DATE, "_tall_mp_consensus_plantago.pdf"), height=42, width=32)
oldpar <- par(mar=c(0,0,0,0))
conc.prr.b <- plot(cons.50r)
add.scale.bar()
mtext("tall MP, majority rule consensus", font=2, line=-1)
par(oldpar)
dev.off()
