library(ips)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/plantago_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup" & treesp$USE == 1]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier" & treesp$USE == 1]
outliers <- gsub(" ", "_", outliers)

conc <- read.dna("40_concatenated/mm.fasta", format="fasta")
LAB <- sub("__.*$", "", labels(conc))
OUT <- labels(conc)[LAB %in% outgroups]
## OUT <- "Littorella_australis__P-1258_trnl_P-1258" # in case if there are no real otgroups in morph matrix

EXC <- labels(conc)[LAB %in% outliers] # used!
conc <- conc[!labels(conc) %in% EXC, ] # remove outliers

setwd("70_mrbayes_working")
tr <- MrBayes(conc, file="mm", burnin=5000, run=T)
## tr <- read.nexus("mm.con.tre")
setwd("..")

tr <- tr[[1]]
tr <- root(tr, outgroup=OUT, resolve.root=T)
tr$node.label <- suppressWarnings(round(as.numeric(tr$node.label)*100)) # warning is OK

pdf(paste("99_mp_mb_trees/", DATE, "_mm_mb_plantago.pdf", sep=""), height=36, width=32)
oldpar <- par(mar=c(0,0,0,0))
plot(tr)
nodelabels(tr$node.label, frame="none", bg="transparent", adj=-0.1)
mtext("mm its + trnl + morph MB", font=2, line=-3)
add.scale.bar()
dev.off()
##
tr$node.label[tr$node.label == "NA"] <- ""
write.tree(tr, file=paste("99_mp_mb_trees/", DATE, "_mm_mb_plantago.tre", sep=""))
