library(shipunov)
library(ape)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")
treesp <- read.table("../../data/plantago_treesp.txt", sep="\t", h=T, as.is=T)
outgroups <- treesp$SPECIES.NEW[treesp$TYPE == "outgroup" & treesp$USE == 1]
outgroups <- gsub(" ", "_", outgroups)

outliers <- treesp$SPECIES.NEW[treesp$TYPE == "outlier" & treesp$USE == 1]
outliers <- gsub(" ", "_", outliers)

conc <- Read.fasta("40_concatenated/morph.fasta")
bb <- do.call(rbind, strsplit(conc$sequence, split=""))
bb[bb == "A"] <- 1
bb[bb == "C"] <- 0
row.names(bb) <- conc$name
## MrBayes restriction is 99 chars
row.names(bb)[nchar(row.names(bb)) > 90] <- paste0(substr(row.names(bb), 1, 95), "_etc")

LAB <- sub("__.*$", "", conc$name)
OUT <- conc$name[LAB %in% outgroups]
EXC <- conc$name[LAB %in% outliers] # is not used

setwd("70_mrbayes_working")
tr <- MrBayes(bb, file="morph", burnin=5000, run=TRUE, method="mixed")
## tr <- read.nexus("morph.con.tre")
setwd("..")

tr <- tr[[1]]
tr <- root(tr, outgroup=OUT, resolve.root=T)
tr$node.label <- suppressWarnings(round(as.numeric(tr$node.label)*100)) # warning is OK

pdf(paste("99_mp_mb_trees/", DATE, "_morph_mb_plantago.pdf", sep=""), height=36, width=32)
oldpar <- par(mar=c(0,0,0,0))
plot(tr)
nodelabels(tr$node.label, frame="none", bg="transparent", adj=-0.1)
mtext("morph MB", font=2, line=-3)
add.scale.bar()
dev.off()
##
tr$node.label[tr$node.label == "NA"] <- ""
write.tree(tr, file=paste("99_mp_mb_trees/", DATE, "_morph_mb_plantago.tre", sep=""))
