library(ips)
library(shipunov)

DATE <- format(Sys.time(), "%Y%m%d_%H%M%S")

treesp <- read.table("../../data/plantago_treesp.txt", sep="\t", h=T, as.is=T)
subgp <- treesp$SPECIES.NEW[treesp$TYPE == "subgp" & treesp$USE == 1]
subgp <- c(subgp, "Plantago coronopus") # outgroup
subgp <- gsub(" ", "_", subgp)

outgroups <- "Plantago coronopus"
outgroups <- gsub(" ", "_", outgroups)

conc <- read.dna("40_concatenated/semistrict_orig.fasta", format="fasta")
LAB <- sub("__.*$", "", labels(conc))
OUT <- labels(conc)[LAB %in% outgroups]

SUBGP <- labels(conc)[LAB %in% subgp]
conc <- conc[labels(conc) %in% SUBGP, ] # leave subgenus Plantago only + outgroup
lconc <- dimnames(conc)[[1]]
lconc[nchar(lconc) > 90] <- paste0(substr(lconc[nchar(lconc) > 90], 1, 95), "_etc") # MrBayes restriction
dimnames(conc)[[1]] <- lconc

setwd("70_mrbayes_working")
tr <- MrBayes(conc, file="subgp", burnin=5000, run=TRUE, temp=0.15, nchains=8)
## tr <- read.nexus("subgp.con.tre")
setwd("..")

tr <- tr[[1]]
tr <- root(tr, outgroup=OUT, resolve.root=TRUE)
tr$node.label <- suppressWarnings(round(as.numeric(tr$node.label)*100)) # warning is OK

pdf(paste("99_mp_mb_trees/", DATE, "_subgp_mb_plantago.pdf", sep=""), height=42, width=32)
oldpar <- par(mar=c(0,0,0,0))
plot(tr)
nodelabels(tr$node.label, frame="none", bg="transparent", adj=-0.1)
mtext("all subg. Plantago MB", font=2, line=-3)
add.scale.bar()
dev.off()
##
tr$node.label[tr$node.label == "NA"] <- ""
write.tree(tr, file=paste("99_mp_mb_trees/", DATE, "_subgp_mb_plantago.tre", sep=""))
